summaryrefslogtreecommitdiffstats
path: root/vespalib
diff options
context:
space:
mode:
authorTor Egge <Tor.Egge@yahooinc.com>2022-04-06 16:54:11 +0200
committerTor Egge <Tor.Egge@yahooinc.com>2022-04-06 16:54:11 +0200
commit730fddd9578d3fc1a623fa618763b091b98551c2 (patch)
treeeea82f31230a4667e8d4d12e49c062d229278c55 /vespalib
parentbd880deb08ddca54e5fce63763e86af59bfbce88 (diff)
Fix typos in class comments. Rename get_read_view() to make_read_view().
Diffstat (limited to 'vespalib')
-rw-r--r--vespalib/src/vespa/vespalib/util/rcuvector.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/vespalib/src/vespa/vespalib/util/rcuvector.h b/vespalib/src/vespa/vespalib/util/rcuvector.h
index e3e17d8edf0..ce48082099c 100644
--- a/vespalib/src/vespa/vespalib/util/rcuvector.h
+++ b/vespalib/src/vespa/vespalib/util/rcuvector.h
@@ -150,11 +150,11 @@ public:
const T& get_elem_ref(size_t i) const noexcept { return _data[i]; } // Called from writer only
/*
* Readers holding a generation guard can call get_read_view() to
* get a read view to the rcu vector. Array bound (read_size) must
* be specified by reader, cf. committed docid limit in attribute vectors.
*/
- ConstArrayRef<T> get_read_view(size_t read_size) const noexcept {
+ ConstArrayRef<T> make_read_view(size_t read_size) const noexcept {
return ConstArrayRef<T>(&acquire_elem_ref(0), read_size);
}
@@ -150,11 +150,11 @@ public:
const T& get_elem_ref(size_t i) const noexcept { return _data[i]; } // Called from writer only
/*
- * Readers holding a generation guard can call get_read_view() to
+ * Readers holding a generation guard can call make_read_view() to
* get a read view to the rcu vector. Array bound (read_size) must
* be specified by reader, cf. committed docid limit in attribute vectors.